@@ -1,6 +1,6 @@
-from .CTE import DAG_FP, INPUT_FP, MF_FP, OUTPUT_FP, SNAKEMAKE_EXIT_CODE_FP
+from .CTE import DAG_FP, INPUT_FP, MF_FP, OUTPUT_FP, LOG_DB_FP
 from .debug import debug_print, filtered_environment
-from .error import handle_unknown_exception
+from .error import handle_exception
 from .image import default_rule_parameters, get_tools
 from .io import download_resource, load_json, save_json
 from .run import run_bx_job, run_command
